#!/usr/bin/perl -w
#########################################################################
#
# Serz Minus (Sergey Lepenkov), <abalama@cpan.org>
#
# Copyright (C) 1998-2020 D&D Corporation. All Rights Reserved
#
# This is free software; you can redistribute it and/or modify it
# under the same terms as Perl itself.
#
# $Id: 03-tools.t 58 2020-04-14 09:30:30Z abalama $
#
#########################################################################
use Test::More tests => 10;
BEGIN { use_ok('VISD::Tools') };


# RRDtools
SKIP: {
    skip("RRDtool is not installed", 2) unless HAVE_RRDTOOLS;
    skip("RRDtool version >= 1.5 required", 2) unless RRDs->VERSION >= 1.5;
    #ok(VISD::Tools->VERSION, 'Version');

    my $file = "sys.rrd";
    my $type = "sys";

    # Create RRD database
    my ($rrdstatus, $rrdmsg) = rrd_create(
        file => $file,
        type => $type,
        step => 20,
    );
    ok($rrdstatus, "Create RRD database") or diag $rrdmsg;

    # Update RRD database
    ($rrdstatus, $rrdmsg) = rrd_update(
        file => $file,
        type => $type,
        ## data:
        cpu => 12,
        mem => 24,
        swp => 6,
        iod => 10,
    );
    ok($rrdstatus, "Update RRD database") or diag $rrdmsg;
}

# dev2name
{
    is(dev2name("/dev/foo"), "dev_foo", "Foo device");
    is(dev2name("/dev/foo/bar/baz"), "dev_foo_bar_baz", "Baz device");
}

# req_or_avail
{
#    my ($status, $message) = fetch("http://localhost/aa1aa/last_data.json", ".", 10);
#    ok($status, "Get remote resource") or note($message);
    is(join(",", req_or_avail([qw/foo bar/], [qw/foo bar baz/])), "foo,bar", "foo, bar");
    is(join(",", req_or_avail([qw/foo bar quux/], [qw/foo bar baz/])), "foo,bar", "foo, bar without quux");
    is(join(",", req_or_avail([qw/one two/], [qw/foo bar baz/])), "", "Nothing returns");
    is(join(",", req_or_avail([], [qw/foo bar baz/])), "foo,bar,baz", "foo, bar, baz 1");
    is(join(",", req_or_avail(undef, [qw/foo bar baz/])), "foo,bar,baz", "foo, bar, baz 2");
    #my @sel = req_or_avail([], [qw/foo bar baz/]); # Returns foo, bar, baz
}

__END__
